@@ -29,7 +29,8 @@ def elapsed_timer():
 
 with elapsed_timer() as elapsed:
     sherlock = sherlock_explorer.SherlockExplorer()
-    sherlock.explore_object("TIC 251848941", input_lc_file="/home/martin/Downloads/ch_det.dat", auto_detrend_periodic_signals=False,
+    sherlock.explore_object("TIC 257605131", input_lc_file="../TIC257605131_INP/lc_2.csv",
+                            auto_detrend_periodic_signals=False,
                             smooth=False, cadence=120)
 
     # sherlock = sherlock_class.Sherlock(n_detrends=3, auto_detrend_periodic_signals=True,
